/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDEVELOPER
 * Version: 1.0
 */

using NUnit.Framework;
using System;
using System.Collections;
using System.Globalization;
using TopCoder.Document.Index.WordStreams;

namespace TopCoder.Document.Index.Persistence.DB
{
    /// <summary>
    /// This class tests <see cref="DBDocumentIndexParameters"/>, it's also a base class to
    /// <see cref="TestDBDocumentIndexParameters"/>.
    /// </summary>
    [TestFixture]
    public class TestDBDocumentIndexParameters : TestDBPersistenceParameters
    {
        /// <summary>
        /// Initializes <see cref="TestDBPersistenceParameters.testObject"/>.
        /// </summary>
        public TestDBDocumentIndexParameters()
        {
            testObject[0] = new DBDocumentIndexParameters("test", 0);
            testObject[1] = new DBDocumentIndexParameters("test", 0);
            testObject[2] = new DBDocumentIndexParameters("test", 1);
        }

        /// <summary>
        /// <c>testObject[0]</c> can never be equal to <see cref="DBPersistenceParameters"/> instance.
        /// </summary>
        [Test]
        public void TestEqualsPersistenceParameters()
        {
            Assert.IsFalse(testObject[0].Equals(new DBPersistenceParameters("test")),
                "Not equal to superclass.");
        }

        /// <summary>
        /// Tests the property <see cref="DBDocumentIndexParameters.DocumentID"/>.
        /// </summary>
        [Test]
        public void TestDocumentID()
        {
            Assert.AreEqual(0, (testObject[0] as DBDocumentIndexParameters).DocumentID, "Incorrect document ID 0");
            Assert.AreEqual(0, (testObject[1] as DBDocumentIndexParameters).DocumentID, "Incorrect document ID 1");
            Assert.AreEqual(1, (testObject[2] as DBDocumentIndexParameters).DocumentID, "Incorrect document ID 1");
        }
    }

    /// <summary>
    /// This class tests the constructors of <see cref="DBDocumentIndexParameters"/>.
    /// </summary>
    [TestFixture]
    public class TestDBDocumentIndexParametersConstructors
    {
        /// <summary>
        /// Tests a null connection name to the constructor.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void TestConstructorNull()
        {
            new DBDocumentIndexParameters(null, 0);
        }

        /// <summary>
        /// Tests an empty connection name to the constructor.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentException))]
        public void TestConstructorEmpty()
        {
            new DBDocumentIndexParameters(" ", 0);
        }

        /// <summary>
        /// Tests a negative document ID.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentOutOfRangeException))]
        public void TestConstructorNegative()
        {
            new DBDocumentIndexParameters("test", -1);
        }
    }
}
